==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/NetworkSecurityGroupResourceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Defines the NSG resource settings.
 * @property resourceType The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
 * Expected value is 'Microsoft.Network/networkSecurityGroups'.
 * @property securityRules Gets or sets Security rules of network security group.
 * @property tags Gets or sets the Resource tags.
 * @property targetResourceGroupName Gets or sets the target resource group name.
 * @property targetResourceName Gets or sets the target Resource name.
 */
public data class NetworkSecurityGroupResourceSettingsArgs(
    public val resourceType: Output<String>,
    public val securityRules: Output<List<NsgSecurityRuleArgs>>? = null,
    public val tags: Output<Map<String, String>>? = null,
    public val targetResourceGroupName: Output<String>? = null,
    public val targetResourceName: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs.builder()
            .resourceType(resourceType.applyValue({ args0 -> args0 }))
            .securityRules(
                securityRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tags(tags?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .targetResourceGroupName(targetResourceGroupName?.applyValue({ args0 -> args0 }))
            .targetResourceName(targetResourceName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkSecurityGroupResourceSettingsArgs].
 */
@PulumiTagMarker
public class NetworkSecurityGroupResourceSettingsArgsBuilder internal constructor() {
    private var resourceType: Output<String>? = null

    private var securityRules: Output<List<NsgSecurityRuleArgs>>? = null

    private var tags: Output<Map<String, String>>? = null

    private var targetResourceGroupName: Output<String>? = null

    private var targetResourceName: Output<String>? = null

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Network/networkSecurityGroups'.
     */
    @JvmName("tucncxxdpxefgcrp")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value Gets or sets Security rules of network security group.
     */
    @JvmName("tmywdpfwsreialjq")
    public suspend fun securityRules(`value`: Output<List<NsgSecurityRuleArgs>>) {
        this.securityRules = value
    }

    @JvmName("aijausnefbbmnere")
    public suspend fun securityRules(vararg values: Output<NsgSecurityRuleArgs>) {
        this.securityRules = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets Security rules of network security group.
     */
    @JvmName("bmniwfkbxlegnguy")
    public suspend fun securityRules(values: List<Output<NsgSecurityRuleArgs>>) {
        this.securityRules = Output.all(values)
    }

    /**
     * @param value Gets or sets the Resource tags.
     */
    @JvmName("conyjelapnxwpmgs")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("etsljuwjvmtxwgjk")
    public suspend fun targetResourceGroupName(`value`: Output<String>) {
        this.targetResourceGroupName = value
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("cmbprjuqpidlksja")
    public suspend fun targetResourceName(`value`: Output<String>) {
        this.targetResourceName = value
    }

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Network/networkSecurityGroups'.
     */
    @JvmName("wkensjuhjuaetiop")
    public suspend fun resourceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value Gets or sets Security rules of network security group.
     */
    @JvmName("gcjqusgybrrrshxx")
    public suspend fun securityRules(`value`: List<NsgSecurityRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.securityRules = mapped
    }

    /**
     * @param argument Gets or sets Security rules of network security group.
     */
    @JvmName("aylqkolkanhbdrbc")
    public suspend fun securityRules(argument: List<suspend NsgSecurityRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NsgSecurityRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.securityRules = mapped
    }

    /**
     * @param argument Gets or sets Security rules of network security group.
     */
    @JvmName("qdycfyoelvernbru")
    public suspend fun securityRules(vararg argument: suspend NsgSecurityRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            NsgSecurityRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.securityRules = mapped
    }

    /**
     * @param argument Gets or sets Security rules of network security group.
     */
    @JvmName("ktietsyvqupajpnd")
    public suspend fun securityRules(argument: suspend NsgSecurityRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NsgSecurityRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.securityRules = mapped
    }

    /**
     * @param values Gets or sets Security rules of network security group.
     */
    @JvmName("krvbigxoxrewpilp")
    public suspend fun securityRules(vararg values: NsgSecurityRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.securityRules = mapped
    }

    /**
     * @param value Gets or sets the Resource tags.
     */
    @JvmName("soakkpqubaspjlgm")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Gets or sets the Resource tags.
     */
    @JvmName("qfmcgstgynqtccfu")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("emcedmykqwjofgog")
    public suspend fun targetResourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceGroupName = mapped
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("nlkadabseuprrrcv")
    public suspend fun targetResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetResourceName = mapped
    }

    internal fun build(): NetworkSecurityGroupResourceSettingsArgs =
        NetworkSecurityGroupResourceSettingsArgs(
            resourceType = resourceType ?: throw PulumiNullFieldException("resourceType"),
            securityRules = securityRules,
            tags = tags,
            targetResourceGroupName = targetResourceGroupName,
            targetResourceName = targetResourceName ?: throw PulumiNullFieldException("targetResourceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/NetworkSecurityGroupResourceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Defines the NSG resource settings.
 * @property resourceType The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
 * Expected value is 'Microsoft.Network/networkSecurityGroups'.
 * @property securityRules Gets or sets Security rules of network security group.
 * @property tags Gets or sets the Resource tags.
 * @property targetResourceGroupName Gets or sets the target resource group name.
 * @property targetResourceName Gets or sets the target Resource name.
 */
public data class NetworkSecurityGroupResourceSettingsArgs(
    public val resourceType: Output<String>,
    public val securityRules: Output<List<NsgSecurityRuleArgs>>? = null,
    public val tags: Output<Map<String, String>>? = null,
    public val targetResourceGroupName: Output<String>? = null,
    public val targetResourceName: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs =
        com.pulumi.azurenative.migrate.inputs.NetworkSecurityGroupResourceSettingsArgs.builder()
            .resourceType(resourceType.applyValue({ args0 -> args0 }))
            .securityRules(
                securityRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tags(tags?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .targetResourceGroupName(targetResourceGroupName?.applyValue({ args0 -> args0 }))
            .targetResourceName(targetResourceName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkSecurityGroupResourceSettingsArgs].
 */
@PulumiTagMarker
public class NetworkSecurityGroupResourceSettingsArgsBuilder internal constructor() {
    private var resourceType: Output<String>? = null

    private var securityRules: Output<List<NsgSecurityRuleArgs>>? = null

    private var tags: Output<Map<String, String>>? = null

    private var targetResourceGroupName: Output<String>? = null

    private var targetResourceName: Output<String>? = null

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Network/networkSecurityGroups'.
     */
    @JvmName("eupqycjxutgirwpj")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value Gets or sets Security rules of network security group.
     */
    @JvmName("kctkknwxtcrwjmeg")
    public suspend fun securityRules(`value`: Output<List<NsgSecurityRuleArgs>>) {
        this.securityRules = value
    }

    @JvmName("yauwudmspawnsaln")
    public suspend fun securityRules(vararg values: Output<NsgSecurityRuleArgs>) {
        this.securityRules = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets Security rules of network security group.
     */
    @JvmName("wgnsphwwxdpyiqox")
    public suspend fun securityRules(values: List<Output<NsgSecurityRuleArgs>>) {
        this.securityRules = Output.all(values)
    }

    /**
     * @param value Gets or sets the Resource tags.
     */
    @JvmName("ufhqvvxvgujfbmim")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("pwmtsaqhdwbatrrh")
    public suspend fun targetResourceGroupName(`value`: Output<String>) {
        this.targetResourceGroupName = value
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("xvrkojeojrhjxabk")
    public suspend fun targetResourceName(`value`: Output<String>) {
        this.targetResourceName = value
    }

    /**
     * @param value The resource type. For example, the value can be Microsoft.Compute/virtualMachines.
     * Expected value is 'Microsoft.Network/networkSecurityGroups'.
     */
    @JvmName("msrpdrulkdgvlqat")
    public suspend fun resourceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value Gets or sets Security rules of network security group.
     */
    @JvmName("fapahyktoquvrmgr")
    public suspend fun securityRules(`value`: List<NsgSecurityRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.securityRules = mapped
    }

    /**
     * @param argument Gets or sets Security rules of network security group.
     */
    @JvmName("obxkmidsmofmdhgb")
    public suspend fun securityRules(argument: List<suspend NsgSecurityRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NsgSecurityRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.securityRules = mapped
    }

    /**
     * @param argument Gets or sets Security rules of network security group.
     */
    @JvmName("mdkhjcndvgqcyaiw")
    public suspend fun securityRules(vararg argument: suspend NsgSecurityRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            NsgSecurityRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.securityRules = mapped
    }

    /**
     * @param argument Gets or sets Security rules of network security group.
     */
    @JvmName("cqqdimatqhrqvpeo")
    public suspend fun securityRules(argument: suspend NsgSecurityRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NsgSecurityRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.securityRules = mapped
    }

    /**
     * @param values Gets or sets Security rules of network security group.
     */
    @JvmName("drqcuxekwnxmpdvs")
    public suspend fun securityRules(vararg values: NsgSecurityRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.securityRules = mapped
    }

    /**
     * @param value Gets or sets the Resource tags.
     */
    @JvmName("acnvpfrnaqsriiav")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Gets or sets the Resource tags.
     */
    @JvmName("wrsobaepktvdicgp")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value Gets or sets the target resource group name.
     */
    @JvmName("kwnriufvxlvphald")
    public suspend fun targetResourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetResourceGroupName = mapped
    }

    /**
     * @param value Gets or sets the target Resource name.
     */
    @JvmName("pxurblwqrgxijibg")
    public suspend fun targetResourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetResourceName = mapped
    }

    internal fun build(): NetworkSecurityGroupResourceSettingsArgs =
        NetworkSecurityGroupResourceSettingsArgs(
            resourceType = resourceType ?: throw PulumiNullFieldException("resourceType"),
            securityRules = securityRules,
            tags = tags,
            targetResourceGroupName = targetResourceGroupName,
            targetResourceName = targetResourceName ?: throw PulumiNullFieldException("targetResourceName"),
        )
}
